@@ -2,10 +2,13 @@
 
 from holodeck.lib.errors import ConfigError, HoloDeckError, ValidationError
 from holodeck.lib.errors import FileNotFoundError as HoloDeckFileNotFoundError
+from holodeck.lib.validation import ValidationPipeline, sanitize_tool_output
 
 __all__ = [
     "HoloDeckError",
     "ConfigError",
     "ValidationError",
     "HoloDeckFileNotFoundError",
+    "ValidationPipeline",
+    "sanitize_tool_output",
 ]
