@@ -8,10 +8,18 @@ when configuration is invalid.
 """
 
 from holodeck.models.agent import Agent, Instructions
+from holodeck.models.chat import (
+    ChatConfig,
+    ChatSession,
+    Message,
+    MessageRole,
+    SessionState,
+)
 from holodeck.models.config import DeploymentConfig, GlobalConfig, VectorstoreConfig
 from holodeck.models.evaluation import EvaluationConfig, EvaluationMetric
 from holodeck.models.llm import LLMProvider, ProviderEnum
 from holodeck.models.test_case import FileInput, TestCase, TestCaseModel
+from holodeck.models.token_usage import TokenUsage
 from holodeck.models.tool import (
     FunctionTool,
     MCPTool,
@@ -19,11 +27,18 @@ from holodeck.models.tool import (
     Tool,
     VectorstoreTool,
 )
+from holodeck.models.tool_execution import ToolExecution, ToolStatus
 
 __all__: list[str] = [
     # Agent models
     "Agent",
     "Instructions",
+    # Chat models
+    "ChatConfig",
+    "ChatSession",
+    "Message",
+    "MessageRole",
+    "SessionState",
     # Config models
     "GlobalConfig",
     "VectorstoreConfig",
@@ -31,6 +46,8 @@ __all__: list[str] = [
     # LLM models
     "LLMProvider",
     "ProviderEnum",
+    # Token usage
+    "TokenUsage",
     # Evaluation models
     "EvaluationConfig",
     "EvaluationMetric",
@@ -44,4 +61,7 @@ __all__: list[str] = [
     "FunctionTool",
     "MCPTool",
     "PromptTool",
+    # Tool execution
+    "ToolExecution",
+    "ToolStatus",
 ]
